import sympy as sp
import numpy as np

q,r,s=sp.var('q,r,s')

# data:
# 2x2 contingency table
# 21 2
# 15 3

# indep. rows binomial data model
# parameters pi_1=q pi_2=r
# uniform prior for q,r

# conditional prob. P(data | q, r)
# ignoring a combinatorial constant factor
cPd=q**21*(1-q)**2*r**15*(1-r)**3

# prob. P(data)
# still ignoring that constant factor
Pd=sp.integrate(cPd,(q,0,1),(r,0,1))
print("P(data)",Pd,sp.N(Pd))

# cond. prob. density p(q, r | data)
cpqr=cPd/Pd

# P(q - r < s | data) for s <= 0
lower=sp.integrate(cpqr,(q,0,r+s),(r,-s,1))

# P(q - r > s | data) for s >= 0
upper=sp.integrate(cpqr,(q,r+s,1),(r,0,1-s))

alpha = 0.05 # 1 - alpha = confidence

# table of up to 100 lower tail
# posterior P-values of q - r
# stops when P < alpha / 2
lt=np.arange(0,-1,-.01)
for t in lt:
    P=sp.N(lower.subs(s,t))
    print(t,P)
    if P < alpha / 2:
        break

# analogous table of upper tail values
ut=np.arange(0,1,.01)
for t in ut:
    P=sp.N(upper.subs(s,t))
    print(t,P)
    if P < alpha / 2:
        break


